contains method
Holds when the list has an element equal to value.
Implementation
Condition contains(E value) => _test(_contains, path, [value]);
Holds when the list has an element equal to value.
Condition contains(E value) => _test(_contains, path, [value]);