set method
The change that sets the field to value, or makes it null, for
update. Null gives a required field with a default its default.
Implementation
Change set(V? value) {
if (path.length != 1) {
throw invalidArgument(
'`update` sets the fields of the object itself, not `${path.join('.')}`',
);
}
return Change._(
path.single,
value == null ? null : (writer, _) => _write(writer, value),
);
}