WriteTransaction class final

A write transaction: what a read transaction offers, with this transaction's changes, and the calls that change objects.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

collection<T, Q extends QueryBuilder<T>, K extends Object>(CollectionSchema<T, Q, K> schema) → WriteCollection<T, Q, K>
The collection of schema, for reading and writing its objects.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited