ObjectKind class final
An embedded object, whose fields embedded declares.
Constructors
-
ObjectKind(EmbeddedSchema<
Object?> embedded) -
const
Properties
- code → int
-
The code the stored schema gives the kind.
no setteroverride
-
embedded
→ EmbeddedSchema<
Object?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited