StringListField class final
A list of strings, whose elements can also be tested for how they start and end.
Constructors
-
StringListField(List<
String> path) -
const
Properties
Methods
-
anyEndsWith(
String text) → Condition -
Holds when an element ends with
text. -
anyStartsWith(
String text) → Condition -
Holds when an element starts with
text. -
contains(
String value) → Condition -
Holds when the list has an element equal to
value.inherited -
containsAny(
List< String> values) → Condition -
Holds when an element equals one of
values.inherited -
isNotNull(
) → Condition -
Holds when the field is not null.
inherited
-
isNull(
) → Condition -
Holds when the field is null.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
List< String> ? values) → Change -
The change that sets the list, or makes it null, for
update.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited